@@ -92,9 +92,7 @@ class Api(xuexitong.Xuexitong):
         res = self.requests.get(url,params=data)
 
         result = res.json()
-        print("正在暂时离开中。。。。。")
-        print(result)
-
+        print("正在暂时离开中。。。。。",result)
 
     def signback(self,itemId):
         # 退座
@@ -106,8 +104,7 @@ class Api(xuexitong.Xuexitong):
         res = self.requests.get(url,params=data)
 
         result = res.json()
-        print("正在退座中。。。。。")
-        print(result)
+        print("正在退座中。。。。。",result)
 
     def sign(self,itemId):
         # 签到
@@ -119,8 +116,7 @@ class Api(xuexitong.Xuexitong):
         res = self.requests.get(url,params=data)
 
         result = res.json()
-        print("正在签到中。。。。。")
-        print(result)
+        print("正在签到中。。。。。",result)
 
 
     def cancel(self,itemId):
@@ -135,8 +131,7 @@ class Api(xuexitong.Xuexitong):
         # print(res.request.headers)
         # print(res.headers)
         result = res.json()
-        print("正在取消预约中。。。。。")
-        print(result)
+        print("正在取消预约中。。。。。",result)
 
     def notify(self,msg,wxid):
         data = {"sender":wxid or "L8d99458","data":msg}
